@@ -81,7 +81,7 @@ from io import open
 import atexit
 
 progname = os.path.basename(sys.argv[0])
-progversion = "0.10-py2"
+progversion = "0.11-py2"
 version_blurb = """Demonstration program and cheap test suite for pythondialog.
 
 Copyright (C) 2002-2010, 2013, 2014, 2015  Florent Rougon
@@ -96,11 +96,13 @@ usage = """Usage: {progname} [option ...]
 Demonstration program and cheap test suite for pythondialog.
 
 Options:
-  -t, --test-suite             test all widgets; implies --fast
+  -t, --test-suite             test all widgets; implies '--fast'
   -f, --fast                   fast mode (e.g., makes the gauge demo run faster)
       --debug                  enable logging of all dialog command lines
       --debug-file=FILE        where to write debug information (default:
                                {debug_file} in the current directory)
+  -E, --debug-expand-file-opt  expand the '--file' options in the debug file
+                               generated by '--debug'
       --help                   display this message and exit
       --version                output version information and exit""".format(
     progname=progname, debug_file=default_debug_filename)
@@ -374,7 +376,8 @@ class MyApp(object):
     def setup_debug(self):
         if params["debug"]:
             debug_file = open(params["debug_filename"], "w")
-            d.setup_debug(True, file=debug_file)
+            d.setup_debug(True, file=debug_file,
+                          expand_file_opt=params["debug_expand_file_opt"])
             return debug_file
         else:
             return DummyContextManager()
@@ -1624,11 +1627,12 @@ def process_command_line():
     global params
 
     try:
-        opts, args = getopt.getopt(sys.argv[1:], "ft",
+        opts, args = getopt.getopt(sys.argv[1:], "ftE",
                                    ["test-suite",
                                     "fast",
                                     "debug",
                                     "debug-file=",
+                                    "debug-expand-file-opt",
                                     "help",
                                     "version"])
     except getopt.GetoptError:
@@ -1655,7 +1659,8 @@ def process_command_line():
     params = { "fast_mode": False,
                "testsuite_mode": False,
                "debug": False,
-               "debug_filename": default_debug_filename }
+               "debug_filename": default_debug_filename,
+               "debug_expand_file_opt": False }
 
     # Get the home directory, if any, and store it in params (often useful).
     root_dir = os.sep           # This is OK for Unix-like systems
@@ -1673,6 +1678,8 @@ def process_command_line():
             params["debug"] = True
         elif option == "--debug-file":
             params["debug_filename"] = value
+        elif option in ("-E", "--debug-expand-file-opt"):
+            params["debug_expand_file_opt"] = True
         else:
             # The options (such as --help) that cause immediate exit
             # were already checked, and caused the function to return.
